@@ -1,7 +1,4 @@
 #include <Rcpp.h>
-using namespace Rcpp;
-
-// [[Rcpp::plugins(cpp11)]]
 
 #include "geojson_helpers.h"
 
