@@ -1,7 +1,4 @@
 #include <Rcpp.h>
-using namespace Rcpp;
-
-// [[Rcpp::plugins(cpp11)]]
 
 #include "json.h"
 using json = nlohmann::json;
@@ -10,7 +7,5 @@ using json = nlohmann::json;
 std::string version_nlohmann_json() {
   auto ma = json::meta();
   std::string st = ma.dump();
-  // List ret;
-  // ret["platform"] = ma['platform'];
   return st;
 }
